@@ -1720,13 +1720,10 @@ def insert_first_row_df(df, row):
 def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, drawdown = None):
     safe_r = pd.DataFrame().reindex_like(risky_r)
     safe_r[:] = safe_rate
-    start = 1000
-    floor = 0.8
     dates = risky_r.index
     n_steps = len(dates)
     account_value = start
     floor_value = start * floor
-    m = 3.
     peak = start
 
     account_history = pd.DataFrame().reindex_like(risky_r)
