@@ -211,7 +211,8 @@ def request_samurai_aave_v3_usdc():
     data_aavev3_usdc_df['date'] = pd.to_datetime(data_aavev3_usdc_df['timestamp'], unit='ms')
     data_aavev3_usdc_df = data_aavev3_usdc_df.set_index('date')
     data_aavev3_usdc_df['supply_liquidity'] = data_aavev3_usdc_df['tvl']/(1. + data_aavev3_usdc_df['utilization'])
-    return data_aavev3_usdc_df
+    data_aavev3_usdc_df = data_aavev3_usdc_df.rename(columns={'dapr':'apy'})
+    return data_aavev3_usdc_df[['supply_liquidity','apy']]
 
 
 
@@ -234,7 +235,9 @@ def request_samurai_benqi_usdc():
     data_benqi_usdc_df['date'] = pd.to_datetime(data_benqi_usdc_df['timestamp'], unit='ms')
     data_benqi_usdc_df = data_benqi_usdc_df.set_index('date')
     data_benqi_usdc_df['supply_liquidity'] = data_benqi_usdc_df['tvl']/(1. + data_benqi_usdc_df['utilization'])
-    return data_benqi_usdc_df
+    data_benqi_usdc_df = data_benqi_usdc_df.rename(columns={'dapr':'apy'})
+    return data_benqi_usdc_df[['supply_liquidity','apy']]
+
 
 
 
@@ -257,7 +260,8 @@ def request_samurai_aavev3_savax():
     data_aave_savax_df['date'] = pd.to_datetime(data_aave_savax_df['timestamp'], unit='ms')
     data_aave_savax_df = data_aave_savax_df.set_index('date')
     data_aave_savax_df['supply_liquidity'] = data_aave_savax_df['tvl']/(1. + data_aave_savax_df['utilization'])
-    return data_aave_savax_df
+    data_aave_savax_df = data_aave_savax_df.rename(columns={'dapr':'apy'})
+    return data_aave_savax_df[['supply_liquidity','apy']]
 
 def request_samurai_benqi_savax():
     #https: // yieldsamurai.com / pool / avalanche / 0xf362fea9659cf036792c9cb02f8ff8198e21b4cb
@@ -278,7 +282,8 @@ def request_samurai_benqi_savax():
     data_benqi_savax_df['date'] = pd.to_datetime(data_benqi_savax_df['timestamp'], unit='ms')
     data_benqi_savax_df = data_benqi_savax_df.set_index('date')
     data_benqi_savax_df['supply_liquidity'] = data_benqi_savax_df['tvl']/(1. + data_benqi_savax_df['utilization'])
-    return data_benqi_savax_df
+    data_benqi_savax_df = data_benqi_savax_df.rename(columns={'dapr':'apy'})
+    return data_benqi_savax_df[['supply_liquidity','apy']]
 
 
 def request_samurai_benqi_btcb():
@@ -300,7 +305,8 @@ def request_samurai_benqi_btcb():
     data_benqi_btcb_df['date'] = pd.to_datetime(data_benqi_btcb_df['timestamp'], unit='ms')
     data_benqi_btcb_df = data_benqi_btcb_df.set_index('date')
     data_benqi_btcb_df['supply_liquidity'] = data_benqi_btcb_df['tvl']/(1. + data_benqi_btcb_df['utilization'])
-    return data_benqi_btcb_df
+    data_benqi_btcb_df = data_benqi_btcb_df.rename(columns={'dapr':'apy'})
+    return data_benqi_btcb_df[['supply_liquidity','apy']]
 
 def request_samurai_aave_v3_btcb():
     # https://yieldsamurai.com/pool/avalanche/0x8ffdf2de812095b1d19cb146e4c004587c0a0692
@@ -322,7 +328,8 @@ def request_samurai_aave_v3_btcb():
     data_aavev3_btcb_df = data_aavev3_btcb_df.set_index('date')
     data_aavev3_btcb_df['supply_liquidity'] = data_aavev3_btcb_df['tvl']/(1. + data_aavev3_btcb_df['utilization'])
 
-    return data_aavev3_btcb_df
+    data_aavev3_btcb_df = data_aavev3_btcb_df.rename(columns={'dapr':'apy'})
+    return data_aavev3_btcb_df[['supply_liquidity','apy']]
 
 
 def request_samurai_aave_v3_usdt():
@@ -344,7 +351,8 @@ def request_samurai_aave_v3_usdt():
     data_aavev3_usdt_df['date'] = pd.to_datetime(data_aavev3_usdt_df['timestamp'], unit='ms')
     data_aavev3_usdt_df = data_aavev3_usdt_df.set_index('date')
     data_aavev3_usdt_df['supply_liquidity'] = data_aavev3_usdt_df['tvl']/(1. + data_aavev3_usdt_df['utilization'])
-    return data_aavev3_usdt_df
+    data_aavev3_usdt_df = data_aavev3_usdt_df.rename(columns={'dapr':'apy'})
+    return data_aavev3_usdt_df[['supply_liquidity','apy']]
 
 def request_samurai_benqi_usdt():
     # https://yieldsamurai.com/pool/avalanche/0xd8fcda6ec4bdc547c0827b8804e89acd817d56ef
@@ -365,4 +373,5 @@ def request_samurai_benqi_usdt():
     data_benqi_usdt_df['date'] = pd.to_datetime(data_benqi_usdt_df['timestamp'], unit='ms')
     data_benqi_usdt_df = data_benqi_usdt_df.set_index('date')
     data_benqi_usdt_df['supply_liquidity'] = data_benqi_usdt_df['tvl']/(1. + data_benqi_usdt_df['utilization'])
-    return data_benqi_usdt_df
\ No newline at end of file
+    data_benqi_usdt_df = data_benqi_usdt_df.rename(columns={'dapr':'apy'})
+    return data_benqi_usdt_df[['supply_liquidity','apy']]
\ No newline at end of file
